@@ -27,6 +27,7 @@ class Itol:
             'projectName': '',
             'treeName': '',
             'treeDescription': '',
+            'APIKey': '',
         }
         self.comm = Comm()
 
@@ -82,6 +83,8 @@ if __name__ == "__main__":
         description="iTOL Uploader",
         epilog="Report bugs at https://github.com/albertyw/itolapi/"
     )
+    parser.add_argument(
+        'api_key', help="iTOL API Key")
     parser.add_argument(
         'tree_file', help="path to the tree file to be uploaded to iTOL")
     args = parser.parse_args()
